/* SAS 9.1 for Windows  */

/* Diese Datei: Beisp_01.sas 
   (03.03.2009) */

/* Beispiel 1: Designbasierte Schtzung des Gesamtwertes 
               Zahl der Erwerbslosen 

Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/SAS_Beispiele.zip
*/

/* Vom Forschungsdatenzentrum wird das SAS File "mz02_cf1.sas7bdat" 
(fdz_mikrozensus_cf_2002_sas.zip) ohne SAS format library bereitgestellt. 
Mit 
     OPTIONS NOFMTERR; RUN;
kann das fehlende Format durch das Standardformat ersetzt und der 
Programmabbruch verhindert werden. Das SAS File des FDZ kann dann
wie folgt geffnet werden:
     DATA cf.temp ;
          SET cf.mz02_cf1 (keep = ef1 ef3 ef30 ef504 ef505 ef712);
     (...)
Im Folgenden wird nicht das SAS File des FDZ, sondern das File "mz02cf_Beisp" 
verwendet, das dem SPSS File "mz02cf_Beisp.sav" entspricht
(Download http://www.forschungsdatennetzwerk.de/bestand/mikrozensus/cf/2002/
index.asp, 19.08.2008) 
Modifikationen gegenber den per Download angebotenen Daten:
- Daten enthalten keine fehlenden Werte 
- Rekodierungen und Label in Anlehnung an das Setup fr das Scientific Use File
  Mikrozensus 2002 (siehe www.gesis.org/Dauerbeobachtung/GML/Daten/MZ/mz_2002/
  stata_setup02.htm)
*/


libname library '<Arbeitsverzeichnis>' ;
libname cf '<Arbeitsverzeichnis>' ;


/* Datendefinition */
data  cf.temp ;
  set cf.mz02cf_Beisp (keep = ef1 ef3 ef30 ef504 ef505 ef712);
             /* Schichtung: Bundesland (ef1) x Geb.schicht (ef712) */
     schicht = ef1*10 + ef712;
            /* Auswahlsatz: MZ 1%, CF 3,5% */
     f = 0.01 * 0.035;
            /* Designgewicht */
     w = 1/f;             
            /* ILO-Erwerbslos */
     y = (ef504 eq 2);
            /* Subpopulation: Bev. am Hauptwohns. (ef505), 15+ Jahre (ef30) */
     sub = (ef505<=2 & ef30>=15);
run;
/* Pseudoschicht fr singulre PSU (ef1=4 & ef712=4 Bremen & 
   Gemeinschaftsunterk. => pschicht=34 [Niedersachsen & GU]) 
   wird in SAS nicht bentigt, da singulre PSUs standardgem 
   aus Berechnungen ausgeschlossen werden.
*/


/* Designbasierte Schtzung mit SURVEYMEANS
   R       Auswahlsatz f (s.o.) fr Endlichkeitskorrektur
   SUM     Anforderung von Gesamtwerten
   CLSUM   Anforderung Konfidenzintervall
Design
   STRATA  geschichtete
   CLUSTER einstufige Klumpenstichprobe 
   DOMAIN  Schtzung des Gesamtwertes (y) fr die Subpopulation (sub)
*/
PROC SURVEYMEANS DATA = cf.temp R=0.00035 SUM CLSUM;
	   STRATA  schicht;
	   VAR     y;
	   CLASS   y sub; 
	   DOMAIN  sub;
	   CLUSTER ef3;
	   WEIGHT  w;
RUN;

/* SRSWOR Einfache Zufallsstichprobe, Ziehen mit Zurcklegen */
PROC SURVEYMEANS DATA = cf.temp SUM CLSUM;
	   VAR     y;
	   CLASS   y sub; 
	   DOMAIN  sub;
	   WEIGHT  w;
RUN;

/*
                      S.E._designbasiert    94.763
Design Effekt DEFT = ------------------- = -------- = 1,067
                          S.E._SWSWOR       88.791
*/

/* Alternativ zu "PROC SURVEYMEANS DATA = cf.temp R=0.00035 SUM CLSUM"
PROC SURVEYFREQ DATA=cf.test RATE=0.00035;
     TABLES  sub*y / CLWT ;  
     STRATA  schicht;
     CLUSTER ef3;
     WEIGHT  w; 
run;
*/


