/* SAS 9.1 for Windows  */

/* Diese Datei: Beisp_07.sas 
   (03.03.2009) */

/* 
========================================================================
Beispiel 7: Erwerbslosenquote mit Designgewichtung 
========================================================================

Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/SAS_Beispiele.zip

*/

libname library '<Arbeitsverzeichnis>' ;
libname cf '<Arbeitsverzeichnis>' ;

/* Datendefinition */
data  cf.temp ;
  set cf.mz02cf_Beisp (keep = ef1 ef3 ef4 ef30 ef32 ef52 ef127 ef504 ef505 ef708 ef712) ;
             /* Schichtung: Bundesland (ef1) x Geb.schicht (ef712) */
     schicht = ef1*10 + ef712;
            /* Auswahlsatz: MZ 1%, CF 3,5% */
     f = 0.01 * 0.035;
            /* Designgewicht */
     w = 1/f;             
           /* Region */
     if (ef1>=1 & ef1<=11 & ef708 ne 9) then westost=1; /* West, West-Berlin */
     if (ef1>11 | ef708=9) then westost=2;              /* Ost, Ost-Berlin */
           /* Altersgruppen */ 
     if (ef30<=14) then alter=0;
     if (ef30>=15 & ef30<=24) then alter = 1;
     if (ef30>=25 & ef30<=54) then alter = 2;
     if (ef30>=55 & ef30<=65) then alter = 3;
     if (ef30>=66 & ef30<=99) then alter = 4;
          /* Subpopulation: Bevlkerung am Hauptwohnsitz, 15-65 Jahre, 
                            Erwerbspersonen */
     sub = (ef505>=1 & ef505<=2 & ef30>=15 & ef30<=65 & ef504>=1 & ef504<=2);
         /* Zhlermerkmal: ILO-Erwerbslose x Subpopulation */
     y = (ef504=2) * sub;
         /* Nennermerkmal: Erwerbspersonen x Subpopulation */
     x = (ef504>=1 & ef504<=2) * sub;
 r = 0;
 if (x>0 & y>0) then r = y/x;
run;

/*
Designbasierte Schtzung mit SURVEYMEANS
   R       Auswahlsatz f (s.o.) fr Endlichkeitskorrektur
   SUM     Anforderung von Gesamtwerten
   CLSUM   Anforderung Konfidenzintervall
Design
   STRATA  geschichtete
   CLUSTER einstufige Klumpenstichprobe 
   DOMAIN  Schtzung des Gesamtwertes (y) fr die Subpopulation (sub)
- kein Chi Test
*/

/* Erwerbslosenquote nach Altersgruppen */
proc sort data=cf.temp; by alter; run;
PROC SURVEYMEANS DATA = cf.temp (keep = schicht ef3 w y x r sub alter) R=0.00035 MEAN;
   STRATA  schicht;
   CLUSTER ef3;
   WEIGHT  w;
   ratio y / x; 
   BY alter; 
   CLASS   sub alter;  
   DOMAIN  sub * alter;
RUN;

proc sort data=cf.temp; by alter; run;

proc surveymeans DATA = cf.temp (keep = schicht ef3 w y x sub alter) R=0.00035 ratio;
      strata schicht;
	  cluster ef3;
	  weight w;
	  domain sub * alter;
      var y x; 
      ratio y / x; 
run;
/* SAS-Ergebnisse
alter   sub    Variable   Mean     Std Error of Mean
    1     1    y          0.116608  0.008799
    2     1    y          0.075250  0.002903
    3     1    y          0.111415  0.008507
*/


proc surveymeans DATA = cf.temp (keep = schicht ef3 w y x sub alter westost) R=0.00035 ratio;
      strata schicht;
	  cluster ef3;
	  weight w;
	  domain sub * alter * westost;
      var y x; 
      ratio y / x; 
run;
/* SAS-Ergebnisse
westost alter sub  Mean     Std Error of Mean
      1     1   1  0.088393        0.008688
      1     2   1  0.054173        0.002774
      1     3   1  0.079125        0.007938
      2     1   1  0.223729        0.025269
      2     2   1  0.163500        0.009332
      2     3   1  0.250909        0.027887
*/

quit;
