/* SAS 9.1 for Windows  */

/* Diese Datei: Beisp_08.sas 
   (26.03.2009) */
/* 
==============================================================================
Beispiel 8: Erwerbslosenquote mit gebundener Hochrechnung (Poststratifikation)

Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/SAS_Beispiele.zip


SAS bietet kein Verfahren fr gebundene Hochrechnung (Poststratifikation)          

Alternative: Umsetzung der Formeln in:
Bihler, Wolf, 2008: Parameterschtzungen aus den anonymisierten
   Mikrozensus-Files (II): Gebundene Hochrechnung. ZUMA-Workshop
   "Stichprobendesign und Hochrechnungsverfahren  im Mikrozensus",
   12.-13. Juni 2008. [Folie 10]

Anteil-/Verhltniswert:             R = t_y / t_z 
Anpassungsfaktor:                 c_k = N_g / N_Dach_g 
Hilfsgren fr Varianzschtzung:  u_k = c_k * (v_k - v_sg)
                                   v_k = 1/t_z * (y_k - R*z_k)
Stichprobenmittel v_k in Anpassungsklasse g: v_quer_sg

Beachte: Das Verfahren muss fr jede Subpopulation jeweils extra 
durchgefhrt werden.

Im folgenden Beispiel wird nicht nach Region und Altersgruppe 
differenziert.

Zum Vergleich mit Stata: svy linearized, subpop(sub) : ratio (y/x)
Stata-Ergebnisse: Ratio = 0,0865867  Std. Err. = 0,0027175
==============================================================================
*/



libname library '<Arbeitsverzeichnis>' ;
libname cf '<Arbeitsverzeichnis>' ;


/* Datendefinition */
data  cf.temp ;
  set cf.mz02cf_Beisp (keep = ef1 ef3 ef4 ef30 ef32 ef52 ef127 ef504 ef505 ef708 ef712 ef750g) ;
             /* Schichtung: Bundesland (ef1) x Geb.schicht (ef712) */
     schicht = ef1*10 + ef712;
            /* Auswahlsatz: MZ 1%, CF 3,5% */
     f = 0.01 * 0.035;
            /* Designgewicht */
     w = 1/f;             
          /* Subpopulation: Bevlkerung am Hauptwohnsitz, 15-65 Jahre, 
                            Erwerbspersonen */
     sub = (ef505>=1 & ef505<=2 & ef30>=15 & ef30<=65 & ef504>=1 & ef504<=2);
         /* Zhlermerkmal: ILO-Erwerbslose x Subpopulation */
     y = (ef504=2) * sub;
    wy = y * ef750g * 100; /* gewichtet */
         /* Nennermerkmal: Erwerbspersonen x Subpopulation */
     z = (ef504>=1 & ef504<=2) * sub;
    wz = z * ef750g * 100;  /* gewichtet */
     r = 0;
     if (z>0 & y>0) then r = y/z;
         /* Anpassungsklassen: Geschl. x Staatsangeh., Sold., Wehrpfl. */
     if (ef32=1 & ef52=1 & ef127 ne 9 & ef127 ne 10) then anp=1; /* Deutsche Mnner */
     if (ef32=2 & ef52=1) then anp=2;                            /* Deutsche Frauen */
     if (ef32=1 & ef52 ne 1) then anp=3;                         /* Ausl. Mnner */
     if (ef32=2 & ef52 ne 1) then anp=4;                         /* Ausl. Frauen */
     if (ef32=1 & ef52=1 & ef127=9) then anp=5;                  /* Soldaten */
     if (ef32=1 & ef52=1 & ef127=10) then anp=6;                 /* Wehrpflichtige */
            /* Proxy Anpassungsschicht Bundesland x anp  
                      (extra Schicht fr sub=0) */
     anpschicht = sub*(ef1*10+anp) ;
        /* Hochrechnungsfaktor f. Population und Bev. am Hauptwohnsitz: "SOLL" */
     ng = ef750g*100*(ef505<=2);  /* SPSS: ng */
        /* Designgewicht f. Population und Bev. am Hauptwohnsitz: "Ist" */
     ndachg = w*(ef505<=2);       /* SPSS: ndachg */
        /* Satznummer */
     id = _n_ ;
run;


/* Gesamtwerte Zhler- und Nennermerkmal bei gebundener Hochrechnung */
proc means data=cf.temp (keep = wy wz) noprint ;
     output out=cf.TYTZ sum = ty tz ;   
run;

proc sql;	
	create table cf.temp2
	as
	select *
	from cf.temp, cf.TYTZ
	where 1;
quit;

data  cf.temp ;
  set cf.temp2;
  R_yz = ty/tz ; /* Anteils-/Verhltniswert bei gebundener Hochrechnung: Erwerbslosenquote */
run;

proc sort data = cf.temp; by anpschicht; run;
proc means data=cf.temp (keep = anpschicht ng ndachg) noprint ;
     var ng ndachg;         
     by anpschicht;   
     output out=cf.POP sum = N_g  N_Dach_g ;   
run;

data cf.temp;  
  merge cf.temp cf.POP; 
  by anpschicht ; 
  c_k = N_g / N_Dach_g ;        /* Anpassungsfaktor */
  v_k = 1/tz * (y - R_yz * z) ; /* Hilfsvariablen fr die Varianzschtzung */
run;

proc sort data = cf.temp; by id; run;

/* Stichprobenmittel v_k in Anpassungsklasse g: v_quer_sg */
proc sort data = cf.temp; by anpschicht; run;
proc summary data=cf.temp;
     var v_k;
	 by anpschicht;
     output out=cf.VK  mean(v_k)= v_sg;
run;

data cf.temp;  
  merge cf.temp cf.VK; 
  by anpschicht ; 
  u_k = c_k * (v_k - v_sg); /* Hilfsvariable fr Varianzschtzung */
run;

proc sort data = cf.temp; by id; run;


/* Erwerbslosenquote insgesamt  */
PROC SURVEYMEANS DATA = cf.temp (keep = schicht ef3 w wy wz sub) R=0.00035 MEAN;
   STRATA  schicht;
   CLUSTER ef3;
   WEIGHT  w;
   ratio wy / wz; 
   CLASS   sub;  
   DOMAIN  sub;
RUN;
/* SAS-Ergebnis
Numerator Denominator        Ratio    (Std.Dev. ist irrelevant)
   wy        wz              0.086565 
*/

PROC SURVEYMEANS DATA = cf.temp (keep = schicht ef3 w sub u_k sub) R=0.00035 SUM;
   STRATA  schicht;
   CLUSTER ef3;
   WEIGHT  w;
   var u_k; 
   CLASS   sub;  
   DOMAIN  sub;
RUN;
/* SAS-Ergebnis
  u_k  sub=1     Std Dev     0.002718  (Total ist irrelevant)
*/

quit;
