/* SAS 9.1 for Windows  */

/* Diese Datei: Beisp_10.sas 
   (26.03.2009) */

/* 
==============================================================================
Beispiel 10: Durchschnittliche Arbeitsstunden mit gebundener Hochrechnung 
             (Poststratifikation)                                         

Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/SAS_Beispiele.zip

SAS bietet kein Verfahren fr gebundene Hochrechnung (Poststratifikation)                                                  . 

Alternativ wird das fr Verhltnisschtzungen verwendete Verfahren verwendet
(siehe Beispiel8.sas)

Beachte: Das Verfahren muss fr jede Subpopulation jeweils extra durchgefhrt 
werden. 

Im folgenden Beispiel wird nicht nach Region und Geschlecht differenziert. 
Siehe zum Vergleich mit Stata:
   svyset ef3 [pw = w], strata(schicht) fpc(f) single(certainty) ///
                        poststrata(anpschicht) postweight(M_k)
   svy linearized, subpop(sub) : mean y
Stata-Ergebnisse:  Mean = 36,6   Std. Err. = 0,123096
==============================================================================
*/


libname library '<Arbeitsverzeichnis>' ;
libname cf '<Arbeitsverzeichnis>' ;


/* Datendefinition */
data  cf.temp ;
  set cf.mz02cf_Beisp (keep = ef1 ef3 ef32 ef52 ef127 ef141 ef504 ef505 ef708 ef712 ef750g) ;
             /* Schichtung: Bundesland (ef1) x Geb.schicht (ef712) */
     schicht = ef1*10 + ef712;
            /* Auswahlsatz: MZ 1%, CF 3,5% */
     f = 0.01 * 0.035;
            /* Designgewicht */
     w = 1/f; /* Subpopulation: Bevlkerung am Hauptwohnsitz, Erwerbsttige */
     z = (ef505<=2 & ef504=1); /* Nennermerkmal */
     wz = z * ef750g * 100;    /* Nennermerkmal gewichtet */
	     /* Zhlermerkmal: ef141 Normalerw. geleist. Arbeitszeit Std./Woche. */
     y = ef141;           /* Rekodierung vergrberter Werte auf Klassenmitte */
     if (ef141=57) then y=58; 
     if (ef141=60) then y=62;
     if (ef141=65) then y=67;
     if (ef141=70) then y=72;
     if (ef141=75) then y=77;
     if (ef141=80) then y=82;
     if (ef141=85) then y=87;
     if (ef141=90) then y=93.5;
     wy = y * ef750g * 100;  /* Zhlermerkmal gewichtet */
         /* Anpassungsklassen: Geschl. x Staatsangeh., Sold., Wehrpfl. */
     if (ef32=1 & ef52=1 & ef127 ne 9 & ef127 ne 10) then anp=1; /* Deutsche Mnner */
     if (ef32=2 & ef52=1) then anp=2;                            /* Deutsche Frauen */
     if (ef32=1 & ef52 ne 1) then anp=3;                         /* Ausl. Mnner */
     if (ef32=2 & ef52 ne 1) then anp=4;                         /* Ausl. Frauen */
     if (ef32=1 & ef52=1 & ef127=9) then anp=5;                  /* Soldaten */
     if (ef32=1 & ef52=1 & ef127=10) then anp=6;                 /* Wehrpflichtige */
       /* Proxy Anpassungsschicht Bundesland x anp (extra Schicht fr sub=0) */
     anpschicht = (ef1*10+anp) * z ;
       /* Berechnung des Anpassungsfaktors ("SOLL"):
          Bevlkerung am Hauptwohnsitz, geb. Hochrechnung */
     ng = ef750g*100*(ef505>=1 & ef505<=2);
       /* Designgewichtung ("IST"): Bevlkerung am Hauptwohnsitz */
     ndachg = (1/(0.01*0.035)*(ef505>=1 & ef505<=2));         
     id = _n_ ;    /* Satznummer */
run;

proc sort data = cf.temp; by anpschicht; run;
/* Populationswerte */
proc means data=cf.temp (keep = anpschicht ng ndachg) noprint ;
     var ng ndachg;         
     by anpschicht;   
     output out=cf.POP sum = N_g  N_Dach_g ;   
run;

data cf.temp;  
  merge cf.temp cf.POP; 
  by anpschicht ; 
  c_k = N_g / N_Dach_g ; /* Anpassungsfaktor */ 
run;

proc sort data = cf.temp; by id; run;

/* Gesamtwerte Zhler- und Nennermerkmal bei gebundener Hochrechnung */
proc means data=cf.temp (keep = wy wz) sum noprint; 
     var wy wz; 
     output out=cf.TYTZ 
            sum = ty tz; 
run;

/* Populationswerte ty und ty den Einzeldaten zuspielen */
proc sql;	
	create table cf.temp2
	as
	select *
	from cf.temp, cf.TYTZ
	where 1;
quit;

data  cf.temp ;
  set cf.temp2;
  R_yz = ty/tz ;                /* Mittelwert bei gebundener Hochrechnung */
  v_k = 1/tz * (y - R_yz * z);  /* Hilfsvariable fr die Varianzschtzung */ 
run;


/* Stichprobenmittel v_k in Anpassungsklasse g: v_quer_sg */
proc sort data = cf.temp; by anpschicht; run;
proc summary data=cf.temp;
     var v_k;
	 by anpschicht;
     output out=cf.VK  mean = v_sg;
run;

data cf.temp;  
  merge cf.temp cf.VK; 
  by anpschicht ; 
  u_k = c_k * (v_k - v_sg); /* Hilfsvariable fr Varianzschtzung */
run;

proc sort data = cf.temp; by id; run;

/* Gebundene Hochrechnung Mittelwert (~Ratio; S.E. ist irrelevant) */
proc sort data = cf.temp; by z id; run; 
PROC SURVEYMEANS DATA = cf.temp (keep = schicht ef3 wy wz z w) R=0.00035 mean ;
   STRATA  schicht;
   CLUSTER ef3;
   WEIGHT  w;
   RATIO wy / wz ;
   CLASS   z;
   BY z; 
   DOMAIN  z;
RUN;
/* Ergebnis:  Ratio = 36.625728 */

/* S.E. zum Mittelwert bei gebundener Hochrechnung (Total ist irrelevant) */
PROC SURVEYMEANS DATA = cf.temp (keep = schicht ef3 u_k z w) R=0.00035 SUM STDERR; 
   BY z;
   CLASS z ;
   CLUSTER ef3;
   DOMAIN  z;
   /* RATIO Zhler / Nenner */
   STRATA  schicht;
   VAR     u_k ;
   WEIGHT  w;
RUN;
/* Ergebnis: Std Dev = 0.123128  */

